@@ -167,7 +167,8 @@ class TestOWSave(OWSaveTestBase):
         widget.writer.write.assert_called()
         widget.writer.reset_mock()
 
-        self.iris.X = sp.csr_matrix(self.iris.X)
+        with self.iris.unlocked():
+            self.iris.X = sp.csr_matrix(self.iris.X)
         widget.save_file()
         widget.writer.write.assert_not_called()
 
@@ -239,7 +240,8 @@ class TestOWSave(OWSaveTestBase):
         widget.update_messages()
         self.assertFalse(err.is_shown())
 
-        widget.data.X = sp.csr_matrix(widget.data.X)
+        with self.iris.unlocked():
+            widget.data.X = sp.csr_matrix(widget.data.X)
         widget.update_messages()
         self.assertTrue(err.is_shown())
 
@@ -264,7 +266,8 @@ class TestOWSave(OWSaveTestBase):
         widget.data = self.iris
         self.assertEqual(widget.get_filters(), widget.valid_filters())
 
-        widget.data.X = sp.csr_matrix(widget.data.X)
+        with self.iris.unlocked():
+            widget.data.X = sp.csr_matrix(widget.data.X)
         valid = widget.valid_filters()
         self.assertNotEqual(widget.get_filters(), {})
         # false positive, pylint: disable=no-member
@@ -282,7 +285,8 @@ class TestOWSave(OWSaveTestBase):
         widget.data = self.iris
         self.assertIs(widget.filter, widget.default_valid_filter())
 
-        widget.data.X = sp.csr_matrix(widget.data.X)
+        with self.iris.unlocked():
+            widget.data.X = sp.csr_matrix(widget.data.X)
         self.assertTrue(
             widget.get_filters()[widget.default_valid_filter()]
             .SUPPORT_SPARSE_DATA)
@@ -381,7 +385,8 @@ class TestFunctionalOWSave(WidgetTest):
         widget.auto_save = False
 
         spiris = Table("iris")
-        spiris.X = sp.csr_matrix(spiris.X)
+        with spiris.unlocked():
+            spiris.X = sp.csr_matrix(spiris.X)
 
         for selected_filter, writer in widget.get_filters().items():
             widget.write = writer
